/*******************************************************************************
[		Data Sources		]
* Korea Youth Panel Study (KYPS) 
https://www.nypi.re.kr/archive/contents/siteMain.do?srch_mu_lang=ENG

* Korean School Administrative Data (1999-2002) 
The information is not publicly available for our time window.
Dataset is not available in English.
Contact: Korean Educational Development Institute (KEDI), www.kedi.re.kr

* Education Districts by Provincs and Metropolitan Cities
The Korean School Administrative Data.
Manually mapped to the KYPS Region Codes:
	District_Region_Codes.xlsx

* Resident Population by Provinces and Metropolitan Cities
https://kosis.kr/statHtml/statHtml.do?orgId=101&tblId=DT_1B040A3&conn_path=I2&language=en

* Tax Revenue by Provinces and Metropolitan Cities (Not Available in English)
- Metopolitan Cities
https://kosis.kr/statHtml/statHtml.do?orgId=110&tblId=TX_11007_A056&conn_path=I2
- Provinces
https://kosis.kr/statHtml/statHtml.do?orgId=110&tblId=TX_11007_A057&conn_path=I2
*******************************************************************************/
clear all
clear matrix
clear mata
set more off

	
cap cd Data

global KYPSw1 = "id_dist_w1"

/*******************************************************************************
Bring School Districts from KYPS
*******************************************************************************/
clear
import excel SchoolAdmin/District_Region_Codes.xlsx, firstrow
encode province, gen(provincecode)
drop province
encode educdistr, gen(distrcode_t)
drop educdistr
egen distrcode = group(provincecode distrcode_t)
drop distrcode_t
drop area

gen scharew = regioncode
merge 1:m scharew using id_dist_w1
keep if _m==3
drop _m

// Setting School Districts (Sunham)
gen detailedregion = 1 if inrange(scharew,100,158)                              // Seoul
replace detailedregion = 2 if inrange(scharew,200,269)							// Gangwon-do
replace detailedregion = 3 if inrange(scharew,300,306)							// Daejeon
replace detailedregion = 4 if inrange(scharew,312,357)							// Chungcheongnam
replace detailedregion = 5 if inrange(scharew,360,395)							// Chungcheongbuk
replace detailedregion = 6 if inrange(scharew,400,409) | scharew==417			// Incheon
replace detailedregion = 7 if inrange(scharew,411,415) | inrange(scharew,420,482) // Gyeonggi
replace detailedregion = 8 if inrange(scharew,483,506)							// Gwangju
replace detailedregion = 9 if inrange(scharew,513,550)							// Jeollanam
replace detailedregion = 10 if inrange(scharew,560,597)							// Jeollabuk
replace detailedregion = 11 if inrange(scharew,600,617)							// Busan
replace detailedregion = 12 if inrange(scharew,618,678)							// Gyeongsangnam
replace detailedregion = 13 if inrange(scharew,680,689)							// Ulsan
replace detailedregion = 14 if inrange(scharew,690,699)							// Jeju-do
replace detailedregion = 15 if inrange(scharew,700,711)							// Daegu
replace detailedregion = 16 if inrange(scharew,712,799)							// Gyeongsangbuk

egen regdist = group(detailedregion distrcode)

tempfile morevarsregdistlist regdistlist

	gen altFE = regdist
	replace altFE = 1001 if schlaw ==26
	replace altFE = 1002 if schlaw ==21
	replace altFE = 1003 if inlist(schlaw,22,23,24,25)
	 
	replace altFE=2001 if inlist(schlaw,41)
	replace altFE=2002 if inlist(schlaw,27,28,29,44,46,47)           
	replace altFE=2003 if inlist(schlaw,33,37,38,43)
	replace altFE=2004 if inlist(schlaw,34,35)
	replace altFE=2005 if inlist(schlaw,39,40)
	replace altFE=2006 if inlist(schlaw,30,31)
	replace altFE=2007 if inlist(schlaw,42,36)
	replace altFE=2008 if inlist(schlaw,32,45)

duplicates drop provincecode regioncode, force //do this as the original data is individual level

save `morevarsregdistlist', replace

keep regdist provincecode regioncode distrcode altFE
decode provincecode, gen(province)

save `regdistlist'




/*******************************************************************************
Regional Characteristics
*******************************************************************************/
** Student Move In / Move Out / Dropouts
// School Admin Data 1999-2002: AdminData_i.xlsx, i = 1999-2002

clear
cd SchoolAdmin

tempfile adm1999 adm2000 adm2001 adm2002 moveinout_prelim
forval i = 1999/2002 {
	clear
	import excel AdminData_`i'.xlsx, firstrow
	keep if 학교급 == "중학교"
	collapse (sum) 학생수_총계_계 입학자 전입 전출 학업중단자, by(시도 행정구 교육지원청)
	ren (학생수_총계_계 입학자 전입 전출 학업중단자) (totalstudents`i' entrance`i' movein`i' moveout`i' quit`i')
	ren (시도 행정구 교육지원청) (province region educdistr)
	cap replace region = "포천시" if region == "포천군"
	cap replace region = "광주시" if region == "광주군"
	cap replace region = "양주시" if region == "양주군"
	cap replace region = "화성시" if region == "화성군"
	save `adm`i''
}

use `adm1999'
merge 1:1 province region using `adm2000', nogen
merge 1:1 province region using `adm2001', nogen
merge 1:1 province region using `adm2002', nogen

save `moveinout_prelim'


** Tax Revenue and Population
// Population: PopulationbyRegion.xlsx
// Tax Revenue: (RegionName).xlsx and (RegionName).dta

cd ../Population

tempfile populat
clear
import excel "PopulationbyRegion.xlsx", firstrow
save `populat', replace

cd ..
local fn : dir "TaxRevenue" files "*.xlsx"
cd TaxRevenue
qui foreach f of local fn {
	clear
	local sn: subinstr local f ".xlsx" ""	
	import excel "`sn'.xlsx", firstrow
	ren (B C D E F) (rev1999 rev2000 rev2001 rev2002 rev2003)
	gen province = "`sn'"
	save "`sn'.dta", replace
}

cd ..
clear
local fn : dir "TaxRevenue" files "*.dta"
cd TaxRevenue
foreach f of local fn {
	di "`f'"
	append using "`f'", force
	drop if 시군구별1 == "합계"
	erase `f'
}
ren 시군구별1 region
replace province = "강원"  if province == "강원" 
replace province = "경기"  if province == "경기" 
replace province = "경남"  if province == "경남" 
replace province = "경북"  if province == "경북" 
replace province = "광주"  if province == "광주" 
replace province = "대구"  if province == "대구" 
replace province = "대전"  if province == "대전" 
replace province = "부산"  if province == "부산" 
replace province = "서울"  if province == "서울" 
replace province = "울산"  if province == "울산" 
replace province = "인천"  if province == "인천" 
replace province = "전남"  if province == "전남" 
replace province = "전북"  if province == "전북" 
replace province = "제주"  if province == "제주" 
replace province = "충남"  if province == "충남" 
replace province = "충북"  if province == "충북" 

save ../RegionalTaxRevenue.dta, replace

cd ..
use RegionalTaxRevenue, clear
tempfile taxpop
merge 1:1  province region using `populat'
keep if _merge == 3
drop _merge
save `taxpop', replace

use `moveinout_prelim', clear
merge 1:1  province region using `taxpop'
keep if _merge == 3
drop _merge

save moveinout_tax.dta, replace



/*******************************************************************************
Merge all,
based on
Provincecode/Regioncode/Districtcode Crosswalk (consolidating some large cities)
*******************************************************************************/
clear
tempfile regionc
import excel SchoolAdmin/District_Region_Codes.xlsx, firstrow

// Using Korean is better for merge...
replace province = "강원"  if province == "Gangwon-do"
replace province = "경기"  if province == "Gyeonggi-do" 
replace province = "경남"  if province == "Gyeongsangnam-do" 
replace province = "경북"  if province == "Gyeongsangbuk-do" 
replace province = "광주"  if province == "Gwangju" 
replace province = "대구"  if province == "Daegu" 
replace province = "대전"  if province == "Daejeon" 
replace province = "부산"  if province == "Busan" 
replace province = "서울"  if province == "Seoul" 
replace province = "울산"  if province == "Ulsan" 
replace province = "인천"  if province == "Incheon" 
replace province = "전남"  if province == "Jeollanam-do" 
replace province = "전북"  if province == "Jeollabuk-do" 
replace province = "제주"  if province == "Jeju" 
replace province = "충남"  if province == "Chungcheongnam-do" 
replace province = "충북"  if province == "Chungcheongbuk-do" 
ren area region

// Consolidate
replace region = "고양시" if region == "고양시 덕양구"
replace region = "고양시" if region == "고양시 일산구"
replace region = "부천시" if region == "부천시 소사구"
replace region = "부천시" if region == "부천시 오정구"
replace region = "부천시" if region == "부천시 원미구"
replace region = "성남시" if region == "성남시 분당구"
replace region = "성남시" if region == "성남시 수정구"
replace region = "성남시" if region == "성남시 중원구"
replace region = "수원시" if region == "수원시 권선구"
replace region = "수원시" if region == "수원시 영통구"
replace region = "수원시" if region == "수원시 장안구"
replace region = "수원시" if region == "수원시 팔달구"
replace region = "안산시" if region == "안산시 단원구"
replace region = "안산시" if region == "안산시 상록구"
replace region = "안양시" if region == "안양시 동안구"
replace region = "안양시" if region == "안양시 만안구"
replace region = "포항시" if region == "포항시 남구"
replace region = "포항시" if region == "포항시 북구"
replace region = "전주시" if region == "전주시 덕진구"
replace region = "전주시" if region == "전주시 완산구"
replace region = "청주시" if region == "청주시 상당구"
replace region = "청주시" if region == "청주시 흥덕구"

merge 1:1 regioncode using `regdistlist'		// Wave 1 data - regdist, altFE

keep if _merge == 3
drop _merge
duplicates drop province region, force			// rule out duplicates due to consolidation above
merge 1:1 province region using moveinout_tax.dta	// merge the tax data
keep if _merge == 3


drop _merge province region educdistr
order provincecode regioncode distrcode regdist altFE 

forval i = 1999/2003 {
	cap gen swtchrs`i' = movein`i' + moveout`i'
	cap replace rev`i' = rev`i' / 1000
	
	cap gen swtchrs_adj`i' = swtchrs`i'/totalstudents`i'
	cap gen movein_adj`i' = movein`i'/totalstudents`i'
	cap gen moveout_adj`i' = moveout`i'/totalstudents`i'
	cap gen quit_adj`i' = quit`i'/totalstudents`i'
}

sort altFE

collapse (sum) totalstudents1999 - quit_adj2002, by(altFE)	// Summation by altFE (from regioncode level)

order _all, alpha
egen avg_swtchrs = rowmean(swtchrs1999 swtchrs2000 swtchrs2001 swtchrs2002)
egen avg_moveout = rowmean(moveout1999 moveout2000 moveout2001 moveout2002)
egen avg_movein =  rowmean(movein1999 movein2000 movein2001 movein2002)
egen avg_quit =  rowmean(quit1999 quit2000 quit2001 quit2002)
egen avg_studts =  rowmean(totalstudents1999 totalstudents2000 totalstudents2001 totalstudents2002)
egen avg_swtchrs_adj = rowmean(swtchrs_adj1999-swtchrs_adj2002)
egen avg_moveout_adj = rowmean(moveout_adj1999-moveout_adj2002)
egen avg_movein_adj = rowmean(movein_adj1999-movein_adj2002)
egen avg_quit_adj = rowmean(quit_adj1999-quit_adj2002)

gen taxrev_pc = rev2003/pop2003

reg totalstudent2002 totalstudent1999
predict totalstudentgrowth, residual

cap lab var totalstudentgrowth "Student Population Growth, Predicted"

forval j = 1999/2003 {
	cap lab var totalstudents`j' "# Total Enrolled Students `j'"
	cap lab var entrance`j' "# Entrance `j'"
	cap lab var movein`j' "# Students Moved In   `j'"
	cap lab var moveout`j' "# Students Moved Out   `j'"
	cap lab var swtchrs`j' "# Students Moved In and Out   `j'"
	cap lab var quit`j' "# Students Quit  `j'"
	cap lab var movein_adj`j' "# Students Moved In   `j' (Adjusted by # of Total Enrolled Students)"
	cap lab var moveout_adj`j' "# Students Moved Out   `j' (Adjusted by # of Total Enrolled Students)"
	cap lab var swtchrs_adj`j' "# Students Moved In and Out   `j' (Adjusted by # of Total Enrolled Students)"
	cap lab var swtchrs_adj`j' "# Students Quit `j' (Adjusted by # of Total Enrolled Students)"
	cap lab var quit_adj`j' "# Students Quit  `j' (Adjusted by # of Total Enrolled Students)"
	cap lab var rev`j' "Tax Revenue `j' (Unit: 1,000,000 KRW, inflation unadj)"
	cap lab var pop`j' "# Total Population  `j'"
}

lab var avg_swtchrs "Average Switchers 99-02"
lab var avg_moveout "Average Moved Out 99-02"
lab var avg_movein  "Average Moved In 99-02"
lab var avg_studts  "Average # Total Enrolled Students 99-02"
lab var avg_swtchrs_adj "Adjusted Switchers: (Avg.) Switchers-to-StudentPopulation 99-02"
lab var avg_movein_adj "Adjusted Moved-in: (Avg.) Moved-In-to-StudentPopulation 99-02"
lab var avg_moveout_adj "Adjusted Moved-out: (Avg.) Moved_Out-to-StudentPopulation 99-02"
lab var avg_quit_adj "Adjusted Quit: (Avg.) Quit-to-StudentPopulation 99-02"
lab var taxrev_pc	"Tax Revenue per capita (base: the whole population) 2003"

order altFE avg_swtchrs avg_swtchrs_adj avg_moveout avg_movein avg_studts taxrev_pc

reg taxrev_pc avg_swtchrs_adj,r
reg taxrev_pc avg_moveout_adj,r
reg taxrev_pc avg_movein_adj,r
reg taxrev_pc avg_quit_adj,r



save "RegDistInfo_altFE.dta", replace



/*******************************************************************************
Crosswalk: Area - District - Province and KYPS Schools
*******************************************************************************/
// SUmmarize egion-District list
tempfile cw_prelim cw_prelim2
clear
import excel SchoolAdmin/District_Region_Codes.xlsx, firstrow
encode province, gen(provincecode)
drop province
encode educdistr, gen(distrcode_t)
drop educdistr
egen distrcode = group(provincecode distrcode_t)
drop distrcode_t
drop area

lab var provincecode "Province Code"
lab var distrcode "Education District Code"
lab var regioncode "School Area"
save `cw_prelim', replace

// Merge the Admin data w/ KYPS Schools
use id_dist_w1, clear
keep schla* schare*
drop if missing(schlaw)
duplicates drop schlaw, force
ren scharew regioncode

merge m:1 regioncode using  `cw_prelim'
keep if _merge == 3
drop _merge
save `cw_prelim2', replace

// School List
tempfile regdist
	use `morevarsregdistlist', clear
	keep schla regdist altFE
	duplicates drop schla, force
	drop if missing(regdist)
save `regdist'	// school level data (-schlaw-)

// Attach that to the crosswalk
use `cw_prelim2', clear		// also a school level data
	merge 1:1 schlaw using `regdist', nogen


save KYPSCrosswalk_final.dta, replace

cd ..

/*******************************************************************************
E N D
*******************************************************************************/
