/* Part of Replication files for Sarzosa and Urzua "Bullying Among Adolescents: 
   The Role of Skills" in QE.
   
   Miguel Sarzosa (msarzosa@purdue.edu)
   Sergio Urzua (surzua@econ.umd.edu)
   
   December 2020
   
   This dofile calls Codes/MainRun.do in different versions to run all the models
   we estimate in the paper.
*/


cd Labor/vkorea/Replication

********************************************************************************
* 1. Ensamble Dataset
********************************************************************************

do Codes/1_DataEsambling.do

********************************************************************************
* 2.  Correlated Skills with Hansen, Heckman and Mullen (2004) specification
********************************************************************************
// smoke is a placeholder

do Codes/MainRun.do smoke bullieddum step1_lesscont 1 "" RR
do Codes/MainRun.do smoke bullieddum step1fi 1 "" RR
do Codes/MainRun.do smoke bullieddum step3fi 1 "" RR
do Codes/MainRun.do smoke bullieddum step5fi 1 "" RR
do Codes/MainRun.do smoke bullieddum step6fi 1 "" RR
do Codes/MainRun.do smoke bullieddum step7fi 1 "" RR
do Codes/MainRun.do smoke bullieddum step1 1 "" RR
do Codes/MainRun.do smoke bullieddum step3 1 "" RR
do Codes/MainRun.do smoke bullieddum step5 1 "" RR
do Codes/MainRun.do smoke bullieddum step6 1 "" RR
do Codes/MainRun.do smoke bullieddum step7 1 "" RR

********************************************************************************
* 3. Second stage: Treatment equation
********************************************************************************

do Codes/MainRun.do smoke bullieddum second 2 choiceonly pbullies 
do Codes/MainRun.do smoke bullieddum second 2 choiceonly pviolence 
do Codes/MainRun.do smoke bullieddum second 2 choiceonly pbulviol

********************************************************************************
* 4. Second stage: Outcome equations
********************************************************************************

do Codes/MainRun.do depre_std bullieddum second 2 roy pbulviol

do Codes/MainRun.do smoke bullieddum second 2 roy pbulviol

do Codes/MainRun.do drink bullieddum second 2 roy pbulviol

do Codes/MainRun.do sick bullieddum second 2 roy pbulviol

do Codes/MainRun.do psychoprob bullieddum second 2 roy pbulviol

do Codes/MainRun.do satisfied bullieddum second 2 roy pbulviol

do Codes/MainRun.do inCollege bullieddum second 2 roy pbulviol

do Codes/MainRun.do StressFriends_std bullieddum second 2 roy pbulviol

do Codes/MainRun.do StressParent_std bullieddum second 2 roy pbulviol

do Codes/MainRun.do StressSchool_std bullieddum second 2 roy pbulviol

do Codes/MainRun.do StressTotal_std bullieddum second 2 roy pbulviol

do Codes/MainRun.do StressPoverty_std bullieddum second 2 roy pbulviol

********************************************************************************
* 5a. Second stage: Non-linear Outcome equations (Low-mean Outcomes)
********************************************************************************

do Codes/MainRun.do sick bullieddum second 2 roynl pbulviol

do Codes/MainRun.do psychoprob bullieddum second 2 roynl pbulviol

********************************************************************************
* 5b. Table 9. Treatment equation Additional controls
********************************************************************************

do Codes/MainRun.do smoke bullieddum second 2 choiceonly NC_invest

********************************************************************************
* 6. Simulations: Outcome equations
********************************************************************************

do Codes/MainRun.do depre_std bullieddum bootstrap 2 roy pbulviol

do Codes/MainRun.do smoke bullieddum bootstrap 2 roy pbulviol

do Codes/MainRun.do drink bullieddum bootstrap 2 roy pbulviol

do Codes/MainRun.do sick bullieddum bootstrap 2 roy pbulviol

do Codes/MainRun.do psychoprob bullieddum bootstrap 2 roy pbulviol

do Codes/MainRun.do satisfied bullieddum bootstrap 2 roy pbulviol

do Codes/MainRun.do inCollege bullieddum bootstrap 2 roy pbulviol

do Codes/MainRun.do StressFriends_std bullieddum bootstrap 2 roy pbulviol

do Codes/MainRun.do StressParent_std bullieddum bootstrap 2 roy pbulviol

do Codes/MainRun.do StressSchool_std bullieddum bootstrap 2 roy pbulviol

do Codes/MainRun.do StressTotal_std bullieddum bootstrap 2 roy pbulviol

do Codes/MainRun.do StressPoverty_std bullieddum bootstrap 2 roy pbulviol

do Codes/MainRun.do sick bullieddum bootstrap 2 roynl pbulviol

do Codes/MainRun.do psychoprob bullieddum bootstrap 2 roynl pbulviol

********************************************************************************
* 6. Simulations: Appendix G Quantifying the Impact of a Policy Change
********************************************************************************

do Codes/MainRun.do depre_std bullieddum bootstrapMPC 2 roy pbulviol

do Codes/MainRun.do smoke bullieddum bootstrapMPC 2 roy pbulviol

do Codes/MainRun.do drink bullieddum bootstrapMPC 2 roy pbulviol

do Codes/MainRun.do sick bullieddum bootstrapMPC 2 roy pbulviol

do Codes/MainRun.do psychoprob bullieddum bootstrapMPC 2 roy pbulviol

do Codes/MainRun.do satisfied bullieddum bootstrapMPC 2 roy pbulviol

do Codes/MainRun.do inCollege bullieddum bootstrapMPC 2 roy pbulviol

do Codes/MainRun.do StressFriends_std bullieddum bootstrapMPC 2 roy pbulviol

do Codes/MainRun.do StressParent_std bullieddum bootstrapMPC 2 roy pbulviol

do Codes/MainRun.do StressSchool_std bullieddum bootstrapMPC 2 roy pbulviol

do Codes/MainRun.do StressTotal_std bullieddum bootstrapMPC 2 roy pbulviol

do Codes/MainRun.do StressPoverty_std bullieddum bootstrapMPC 2 roy pbulviol

// Table G.1
do Codes/tabsMPC.do

********************************************************************************
* 7. Results Tables
********************************************************************************
// Table 3
do Codes/DescStats.do

// Table 4
do Codes/MainRun.do "" "" regyd 

// Table 5
do Codes/MainRun.do "" "" tableD

// Table 6
do Codes/MainRun.do "" bullieddum loadings 2 roy pbulviol

// Table 7
do Codes/MainRun.do "" bullieddum GoodFitY 2 roy pbulviol

// Table 8
do Codes/MainRun.do "" bullieddum tablesATEATT 2 roy pbulviol

// Table B.1
do Codes/MainRun.do "" bullieddum tabFS 2 roy pbulviol

// Table C.1
do Codes/MainRun.do "" "" reduced 

// Table C.2
do Codes/MainRun.do "" bullieddum loadsnochoice 2 roy pbulviol

// Table E.1 
do Seoul_AllRegions_Balancing.do 

// Table F.1
do Codes/MainRun.do "" bullieddum GoodFitYnl 2 roynl pbulviol

// Table F.2
do Codes/MainRun.do "" bullieddum tablesATEATTnl 2 roynl pbulviol

// Tables H.1 and H.2
do Codes/MainRun.do "" bullieddum tabSSout 2 roy pbulviol


********************************************************************************
* 8. Results Figures
********************************************************************************

// Figure 1.a
do Codes/MainRun.do "" "" variation

// Figure 1.b
do Codes/MainRun.do "" "" distrib



