*! heterofactor program
*! version 1.2.5
*! 		Branch out from version 1.2.4 to include 4 factors.
*!		Incorporates the residuals to save time
*!      Uses Simulated destibutions for steps where distributions already known 
*! Apr 2013
*! Miguel Sarzosa

capture program drop heterofactor
program heterofactor
	version 11
	if replay() {
		if ("`e(cmd)'" != "heterofactor") error 301
		Replay `0'
	}
	else Estimate `0'
end

capture program drop lfols
program lfols
  version 11
  args lnf xb lnsigma
  local y "$ML_y1"
  quietly replace `lnf' = ln(normalden(`y', `xb',exp(`lnsigma')))
end 

capture program drop Estimate
program Estimate, eclass sortpreserve
	version 11.0
	syntax varlist(min=2 numeric ts) [if] [in], [SCores(varlist ts) INDvarsc(varlist  ts) /// 
		TREATind(varname ts) INStrum(varlist ts) FACTORS(integer 1) NODES(integer 10) /// 
		EXP1(varlist ts) EXP2(varlist ts) EXP3(varlist ts) EXP4(varlist ts) /// 
		TWOSTep FDISTonly NUMF1tests(integer 3) SCNDSTPonly LASTFonlytr choiceonly NOCHOICE ROY ROYNL TREATINDBEF(varlist ts) /// 
		seed(integer 12345) FUTURETESTS INVAR1(varname) INVAR2(varname) /// 
		RESVAR1(varname) RESVAR2(varname) RESVAR3(varname) RESVAR4(varname) RESVAR5(varname) RESVAR6(varname) /// 			 
		stvec(namelist) jointdist(namelist) futureloads(namelist) /// 
		CHOICEFIX gavar(varname) AV1(real -10000) AV2(real 0) AV3(real 0) AV4(real 0) /// 
		TREATIND2(varname ts) CHOICEINCHOICE CHOICEINCHFIX gavar2(varname) ///  
		VECAVLOADS1(namelist) VECAVLOADS0(namelist) ///		
		TRIANGULAR nohats initialreg inipar(namelist) joint Level(cilevel) noLOg *]	
	mlopts mlopts, `options'	
	marksample touse
	gettoken yvar indepvars: varlist, parse(" ")
	local nscores : word count `scores'	
	tokenize `scores'										
	forvalues i = 1/`nscores' {
		tempvar test`i'
		qui gen `test`i''  = ``i''
	}
	local indvarsc1 "`indvarsc' `exp1'"
	local indvarsc2 "`indvarsc' `exp2'"
	local indvarsc3 "`indvarsc' `exp3'"
	local indvarsc4 "`indvarsc' `exp4'"		
	local nx : word count `indepvars'
	local nz : word count `instrum'		
	local nq1 : word count `indvarsc1'
	local nq2 : word count `indvarsc2' 
	local nq3 : word count `indvarsc3'
	local nq4 : word count `indvarsc4'	 	
	local nZ = `nz' + 1
	local nX = `nx' + 1
	local nQ1 = `nq1' + 1
	local nQ2 = `nq2' + 1
	local nQ3 = `nq3' + 1		
	local nQ4 = `nq4' + 1			

	cap scalar drop nodes
	scalar define nodes = `nodes'
	
	if (inlist(`numf1tests',3,6,9)==0) {
		di as error "Option numf1tests must be either 3, 6 or 9. You specified `numf1tests'"
		error 100
	}			
	if 	"`scndstponly'"!= ""  {
		if "`treatind'"=="" & "`nochoice'"=="" & "`futuretests'"=="" { 
			di as error "treatind() and instrum() options required"			
			exit
		}	
	}
	
	if ("`scndstponly'"!="") local nohats "nohats"
	if ("`fdistonly'"!="") local nochoice "nochoice"
	
	if "`joint'"!="" {
		local twostep "twostep"
		if `factors'!=2 {
			di as error "Number of factors using joint option needs to be 2"
			exit		
		}
	}
	if "`choicefix'"!="" & `av1'==-10000 {
		di as error "Need to specify at least av1 when choicefix option used"
		exit	
	}
	
	capture drop _fT* 
	capture drop _MTE_f
	if `factors'>4 | `factors'<1 {
		di as error "Number of factors used needs to be either 1, 2, 3 or 4"
		exit
	}

	markout `touse' `yvar' `indepvars' `treatind' `instrum' `scores' `indvarsc' `exp1' `exp2' `resvar1' `resvar2' `resvar3' `resvar4' `resvar5' `resvar6' `gavar' `gavar1' `gavar2' `treatindbef' `invar1' `invar2'

	qui count if `touse'
	if `r(N)' == 0 {
		error 2000
	}
	capture drop __touse
	gen __touse = `touse'
	
	qui set seed `seed'
	
	if ("`lastfonlytr'"!="" & "`fdistonly'"=="") local fdistonly "fdistonly"
	if ("`lastfonlytr'"!="") local pass = `factors'-1
	
	// Initial Values
	if "`initialreg'"!="" {
		di as text "Estimating" as result " Initial Values Vector"
		if "`scndstponly'"== "" {
			if "`treatindbef'"!="" {
				forvalues j=0/1 {
					local fin = 2 // 3 6
	//				forvalues i=1/`fin' {
					foreach i in 1 2 3 4 6 {
						if (`i'==0) ml model lf lfols ("``i''`j'": `test`i'' = `indvarsc2') (sigT`i'`j':) if `treatindbef'==`j'
						else ml model lf lfols ("``i''`j'": `test`i'' = `indvarsc1',nocons) (sigT`i'`j':) if `treatindbef'==`j'
						qui ml maximize
						mat A=e(b)
						mat bT`i'`j' = A[1,"``i''`j':"]
						local sdT`i'`j' = _b["sigT`i'`j'":_cons]			
					}			
				}
	//			forvalues i=3/6 {
				foreach i in 5 {
					local j=1
					ml model lf lfols ("``i''`j'": `test`i'' = `indvarsc1', nocons) (sigT`i'`j':) if `touse'
					qui ml maximize
					mat A=e(b)
					mat bT`i'`j' = A[1,"``i''`j':"]
					local sdT`i'`j' = _b["sigT`i'`j'":_cons]			
				}						
				qui probit `treatindbef' `instrum'
				mat bprobbef = e(b)	
			}
		}
		if "`scndstponly'"!= "" {
			if "`choiceonly'"!="" | "`roy'"!="" | "`roynl'"!=""  {
				qui probit `treatind' `instrum'
				mat bprobbef = e(b)	
			}	
			if "`nochoice'"!="" {
				ml model lf lfols ("`yvar'": `yvar' = `indepvars') (sY1:)
				qui ml maximize
				mat A=e(b)
				mat bprobbef = A[1,"`yvar':"]
				local sY1 = _b["sY1":_cons]						
			}
			if "`roy'"!="" {
				forvalues d=0/1 {
					ml model lf lfols ("`yvar'`d'": `yvar' = `indepvars') (sY`d':) if `treatind'==`d'
					qui ml maximize
					mat A=e(b)
					mat bY`d' = A[1,"`yvar'`d':"]
					local sY`d' = _b["sY`d'":_cons]						
				}	
			}
			if "`roynl'"!="" {
				forvalues d=0/1 {
					qui gen `yvar'`d' = `yvar'
					qui probit `yvar'`d' `indepvars' if `treatind'==`d'
					mat A=e(b)
					mat bY`d' = A[1,"`yvar'`d':"]	
					drop `yvar'`d'
				}	
			}			
		}
		
		local ini_opt "init(ini_val) search(off)"	
		cap mat drop A
		cap mat drop b

	}
	else local ini_opt "search(on)"
		
	if "`scndstponly'"!= "" {
		di as text "Running" as result " Factor Model"		
		
		if "`triangular'"!="" {	
			scalar define tr = 1
					
			if "`joint'"!="" {
			
				mat _stvec = `stvec' // has to be in exact order: sigT11 sigT21: sigT31 sigT10 sigT20 sigT30 sigT41 sigT51 sigT61 sigT40 sigT60
				mat _dist = `jointdist' // has to be in exact order: sigf11 sigf12 sigf21 sigf22 p1 mu11 mu21 rho1 rho2
				scalar av11 = `av1'
				scalar av12 = `av2'
				
				forvalues T=1/6 {
					cap drop __resbT`T'
					qui gen __resbT`T' = `resvar`T''
				}
				cap drop __D1
				qui gen __D1 = `treatindbef'
				cap drop __ga1
				qui gen __ga1 = `gavar'	
				
				if "`futuretests'"!="" | ("`invar1'"!="" & "`invar2'"!="") {
					forvalues T=1/6 {
						cap drop __resfT`T'
						qui sum ``T'' if `touse'
						qui gen __resfT`T' = ``T'' - `r(mean)'
					}
					mat _futureloads = `futureloads'
					cap drop __D2
					qui gen __D2 = `treatind'
					cap drop __ga2
					qui gen __ga2 = `gavar2'
					scalar av21 = `av3'
					scalar av22 = `av4'
					
					if ("`invar1'"!="" & "`invar2'"!="") {
						cap drop __Inva
						cap drop __Invb
						qui sum `invar1' if `touse'
						qui gen __Inva = `invar1' - `r(mean)'
						qui sum `invar2' if `touse'
						qui gen __Invb = `invar2' - `r(mean)'
					}
				}
				
				local v
				if "`choiceonly'"!="" local v "av21:_cons av22:_cons"
				if "`choiceonly'"!="" local numpar = 13
				if "`nochoice'"!="" local v "a21:_cons a22:_cons"
				if "`nochoice'"!="" local numpar = 14
				if "`nochoice'"!="" local strsy "sY1:_cons"
				if "`roy'"!="" | "`roynl'"!="" local v "av21:_cons av22:_cons a11:_cons a12:_cons a01:_cons a02:_cons"
				if "`roy'"!="" local numpar = 19
				if "`roy'"!="" local strsy "sY1:_cons sY0:_cons"
				if "`roynl'"!="" local numpar = 17
				if "`roynl'"!="" local strsy 
				if "`futuretests'"!="" local v "aa10:_cons ra0:_cons ab10:_cons rb0:_cons aa11:_cons ra1:_cons ab11:_cons rb1:_cons" //"a11:_cons a12:_cons a21:_cons a22:_cons a31:_cons a32:_cons a41:_cons a42:_cons a51:_cons a52:_cons a61:_cons a62:_cons"
				if "`futuretests'"!="" local numpar = 35
				if "`futuretests'"!="" | ("`invar1'"!="" & "`invar2'"!="") local strsy "sfT10:_cons sfT20:_cons sfT30:_cons sfT40:_cons sfT50:_cons sfT60:_cons sfT11:_cons sfT21:_cons sfT31:_cons sfT41:_cons sfT51:_cons sfT61:_cons"
				if "`futuretests'"!="" | ("`invar1'"!="" & "`invar2'"!="") local strmy "mT21:_cons mT31:_cons mT41:_cons mT51:_cons" //mT11:_cons  mT61:_cons mT10:_cons mT20:_cons mT30:_cons mT40:_cons mT50:_cons mT60:_cons"
				if "`invar1'"!="" & "`invar2'"!="" local strli "ja1:_cons ja2:_cons jb1:_cons jb2:_cons sIa:_cons sIb:_cons"
				if "`invar1'"!="" & "`invar2'"!="" local numpar = 45
				if "`invar1'"!="" & "`invar2'"!="" local v "aa10:_cons aa20:_cons ra0:_cons ab10:_cons ab20:_cons rb0:_cons aa11:_cons aa21:_cons ra1:_cons ab11:_cons ab21:_cons rb1:_cons" 
				
				if "`initialreg'"!="" {
					if ("`inipar'" != "") mat ini_par = `inipar'
					if ("`inipar'" == "") mat ini_par = J(1,`numpar',0)
					mat rown ini_par = y1
					mat coln ini_par = `v' aT111:_cons aT211:_cons aT311:_cons aT411:_cons aT421:_cons aT511:_cons aT521:_cons aT110:_cons aT210:_cons aT410:_cons aT420:_cons `strsy' `strmy' `strli'
					if "`futuretests'"=="" & ("`invar1'"=="" & "`invar2'"=="") & "`roy'"=="" & "`roynl'"=="" mat ini_val = bprobbef, ini_par
					if "`futuretests'"=="" & ("`invar1'"=="" & "`invar2'"=="") & ("`roy'"!="" | "`roynl'"!="") mat ini_val = bprobbef, bY1, bY0, ini_par
					if "`futuretests'"!="" | ("`invar1'"!="" & "`invar2'"!="") mat ini_val = ini_par
				}
				
				if "`choiceonly'"!="" {
					ml model d0 factorevaljointprodtr2HHMchoice() ("`treatind'": `treatind' = `instrum') /// 
											/av21 /av22 /aT111 /aT211 /aT311 /aT411 /aT421 /aT511 /aT521 /aT110 /aT210 /aT410 /aT420 /// 
											if `touse', /// 							
											missing `mlopts' `log' 	maximize `ini_opt'					
				}
				if "`nochoice'"!="" {
					ml model d0 fevaljointprodtr2HHMnochoice() ("`yvar'": `yvar' = `indepvars') /// 
											/a21 /a22 /aT111 /aT211 /aT311 /aT411 /aT421 /aT511 /aT521 /aT110 /aT210 /aT410 /aT420 /sY1 /// 
											if `touse', /// 							
											missing `mlopts' `log' 	maximize `ini_opt'						
				}
				if "`roy'"!="" {
					ml model d0 factorevaljointprodtr2HHMroy() ("`treatind'": `treatind' = `instrum') ("`yvar'1": `yvar' = `indepvars') ("`yvar'0": `yvar' = `indepvars') /// 
											/av21 /av22 /a11 /a12 /a01 /a02 /aT111 /aT211 /aT311 /aT411 /aT421 /aT511 /aT521 /aT110 /aT210 /aT410 /aT420 /sY1 /sY0 /// 
											if `touse', /// 							
											missing `mlopts' `log' 	maximize `ini_opt'						
				}
				if "`roynl'"!="" {
					ml model d0 factorevaljointprodtr2HHMroynl() ("`treatind'": `treatind' = `instrum') ("`yvar'1": `yvar' = `indepvars') ("`yvar'0": `yvar' = `indepvars') /// 
											/av21 /av22 /a11 /a12 /a01 /a02 /aT111 /aT211 /aT311 /aT411 /aT421 /aT511 /aT521 /aT110 /aT210 /aT410 /aT420 /// 
											if `touse', /// 							
											missing `mlopts' `log' 	maximize `ini_opt'						
				}				
				if "`futuretests'"!="" {
					ml model d0 factorevaljointprodtr2HHMfTnlB2() /aa10 /ra0 /ab10 /rb0 /aa11 /ra1 /ab11 /rb1 /* /a11 /a12 /a21 /a22 /a31 /a32 /a41 /a42 /a51 /a52 /a61 /a62 */ /// 
											/aT111 /aT211 /aT311 /aT411 /aT421 /aT511 /aT521 /aT110 /aT210 /aT410 /aT420 /// 
											/sfT10 /sfT20 /sfT30 /sfT40 /sfT50 /sfT60 /sfT11 /sfT21 /sfT31 /sfT41 /sfT51 /sfT61 /// 
											/* /mT11 */ /mT21 /mT31 /mT41 /mT51 /* /mT61 /mT10 /mT20 /mT30 /mT40 /mT50 /mT60 */ /// 
											if `touse', /// 							
											missing `mlopts' `log' 	maximize `ini_opt'		
				}	
				if "`invar1'"!="" & "`invar2'"!="" {
					ml model d0 fevaljointprodtr2HHMfTnlBInv() /aa10 /aa20 /ra0 /ab10 /ab20 /rb0 /aa11 /aa21 /ra1 /ab11 /ab21 /rb1 /// 
											/aT111 /aT211 /aT311 /aT411 /aT421 /aT511 /aT521 /aT110 /aT210 /aT410 /aT420 /// 
											/sfT10 /sfT20 /sfT30 /sfT40 /sfT50 /sfT60 /sfT11 /sfT21 /sfT31 /sfT41 /sfT51 /sfT61 /// 
											/mT21 /mT31 /mT41 /mT51 /ja1 /ja2 /jb1 /jb2 /sIa /sIb /// 
											if `touse', /// 							
											missing `mlopts' `log' 	maximize `ini_opt'	
											
					cap drop __Inva
					cap drop __Invb																						
				}
				if "`futuretests'"!="" | ("`invar1'"!="" & "`invar2'"!="") {
					forvalues T=1/6 {
						cap drop __resfT`T'
					}
					cap drop __D2
					cap drop __ga2
				}				

				ereturn scalar k_aux = `numpar'		
		
				Replay	, level(`level')
				
				forvalues T=1/6 {
					cap drop __resbT`T'
				}
				cap drop __D1
				
			}
		} // end if triangular!=""

	} // end if scndstponly	==""

	if ("`numpar'"=="") local numpar = `nmpr'			
	
	di as text "Done Estimating Factor Model"
		
	cap drop __touse
//	cap drop __res*
//	cap drop __TD*
	cap scalar drop nodes	
	ereturn local cmd heterofactor	
	
end


cap program drop Replay
program Replay
	syntax [, Level(cilevel) EForm ]
	/*if `e(k_aux)' {
		local sigma1 diparm(sig1,  label("sigma_1"))
		local sigmT1 diparm(sigT1, label("sigma_T1"))
		local sigmT2 diparm(sigT2, label("sigma_T2"))
		local sigmaf diparm(sigf,  label("sigma_f"))
	}*/

	ml display , level(`level') ///`sigma1' `sigmT1' `sigmT2' `sigmaf'

end

