/* Part of Replication files for Sarzosa and Urzua "Bullying Among Adolescents: 
   The Role of Skills" in QE.
   
   Miguel Sarzosa (msarzosa@purdue.edu)
   Sergio Urzua (surzua@econ.umd.edu)
   
   December 2020
   
   This dofile creates the tables and figures in the appendix on "Quantifying 
   the Impact of a Policy Change"
*/

cap cd Results/Simulations

local yvars "depre_std smoke drink sick psychoprob satisfied inCollege StressFriends_std StressParent_std StressSchool_std StressPoverty_std StressTotal_std"

cap file close mpc
file open mpc using HHM/bs/mpc/MPC_table.txt, write replace

file write mpc "\begin{tabular}{lcccccc}" _n "\hline" _n
file write mpc " & \multicolumn{6}{c}{Gains on those who were:} \\ \cline{2-7}" _n
file write mpc " & \multicolumn{2}{c}{Bullied Before \& Not Bullied} & \multicolumn{2}{c}{Bullied Before the} & \multicolumn{2}{c}{Not bullied Before} \\" _n // 
file write mpc " & \multicolumn{2}{c}{After the Policy Change} & \multicolumn{2}{c}{Policy Change} & \multicolumn{2}{c}{the Policy Change} \\" _n //
file write mpc " & \multicolumn{2}{c}{(1)} & \multicolumn{2}{c}{(2)} & \multicolumn{2}{c}{(3)} \\" _n //
file write mpc "Outcome & Diff. & Std.Err. & Diff. & Std.Err. &  Diff. & Std.Err.  \\ " _n "\hline" _n // 
file write mpc " & & & & & & \\ " _n //
foreach out in `yvars' {
	use HHM/bs/mpc/bullieddum_`out'_JointRRpbulviol_trHHM_sgZ_bs.dta, clear
	replace _b_EATE_MPC=. if _b_EATE_MPC==0
	if "`out'"=="depre_std" local tit "Depression"
	if "`out'"=="smoke" local tit "Smoking"
	if "`out'"=="drink" local tit "Drinking"
	if "`out'"=="sick" local tit "Sick"
	if "`out'"=="psychoprob" local tit "Mental Health"
	if "`out'"=="satisfied" local tit "Satisfied"
	if "`out'"=="inCollege" local tit "inCollege"
	if "`out'"=="StressFriends_std" local tit "Stress: Friends"
	if "`out'"=="StressParent_std" local tit "Stress: Parents"
	if "`out'"=="StressSchool_std" local tit "Stress: School"
	if "`out'"=="StressPoverty_std" local tit "Stress: Poverty"
	if "`out'"=="StressTotal_std" local tit "Stress: Total"
	file write mpc  "`tit' "
	foreach T in EATE_MPC ETTE ETUE {
		qui sum _b_`T'
		local m`T' = string(round(`r(mean)',0.0001),"%9.4f")
		local se`T' = string(round(`r(sd)',0.0001),"%9.4f")
		local stars
		if (abs(`r(mean)'/`r(sd)')>=1.645) local stars "*"
		if (abs(`r(mean)'/`r(sd)')>=1.96) local stars "**"
		if (abs(`r(mean)'/`r(sd)')>=2.5758) local stars "***"			
		file write mpc "& `m`T''`stars' & (`se`T'') "
		if "`T'"=="ETUE" file write mpc " \\" _n
	}
}
file write mpc "\hline" _n "\end{tabular}" 
file close mpc

exit
	
local yvars "depre_std smoke drink sick psychoprob satisfied inCollege StressFriends_std StressParent_std StressSchool_std StressPoverty_std StressTotal_std"
foreach outvar in `yvars' {
	use HHM/bs/mpc/bullieddum_`outvar'_JointRRpbulviol`nl'_trHHM_sgZ_bs, clear
	
	local grid=10
	forvalues i = 1/`grid' {
		forvalues h = 1/`grid' {
			replace _b_EATE_12_`i'`h' = . if _b_EATE_12_`i'`h'==0
		}	
	}
	
	local AT "A"
	file open E`AT'TEf12 using HHM/bs/mpc/bullieddum_`outvar'_JointRRpbulviol`nl'_trHHM_sgZ_bs_E`AT'TEf12.txt, write replace
	file open s`AT'TEf12 using HHM/bs/mpc/bullieddum_`outvar'_JointRRpbulviol`nl'_trHHM_sgZ_bs_s`AT'TEf12.txt, write replace
	forvalues i = 1/10 {
		forvalues h = 1/10 {
			qui sum _b_E`AT'TE_12_`i'`h'
			if `r(N)'<175 {
				file write E`AT'TEf12 "nan" _tab
				file write s`AT'TEf12 "nan" _tab
			}
			else {
				file write E`AT'TEf12 "`r(mean)'" _tab
				file write s`AT'TEf12 "`r(sd)'" _tab 
			}	
			if `h'==10 {
				if `r(N)'<175 {
					file write E`AT'TEf12 "nan" _n
					file write s`AT'TEf12 "nan" _n
				}
				else {
					file write E`AT'TEf12 "`r(mean)'" _n
					file write s`AT'TEf12 "`r(sd)'" _n 
				}	
			} 
		}
	}	
	file close E`AT'TEf12
	file close s`AT'TEf12
}
